import axios from '@lib/plug/axios.js'
const api = {
  catalogueCreate: '/api/catalogue/create',
  catalogueUpdate: '/api/catalogue/update',
  catalogueDelete: '/api/catalogue/delete',
  catalogueQuery: '/api/catalogue/query',
  catalogueFetch: '/api/catalogue/fetch',
  dictQuery: '/api/code/dictionary/query',
  journalQuery: '/api/journal/intact/query',
  userQuery: '/api/reader/user/query'
}
const state = () => ({
  Total: 0,
  catalogueList: [],
  journalList: [],
  dict: {},
  userList: [],
  userTotal: 0
})

const actions = {
  async userQuery ({ commit }, { filter, paging } = {}) {
    const res = await axios.get(api.userQuery, { ...filter, skip: paging.page, limit: paging.size })
    commit('userQuery', res)
    return res
  },
  async catalogueCreate ({ commit }, payload) {
    const res = await axios.post(api.catalogueCreate, payload)
    return res
  },
  async catalogueUpdate ({ commit }, payload) {
    const res = await axios.post(api.catalogueUpdate, { ...payload, id: payload._id })
    return res
  },
  async catalogueDelete ({ commit }, { id }) {
    const res = await axios.delete(`${api.catalogueDelete}/${id}`)
    return res
  },
  async catalogueQuery ({ commit }, { filter, paging } = {}) {
    const res = await axios.get(api.catalogueQuery, { ...filter, skip: paging.page, limit: paging.size })
    commit('catalogueQuery', res)
    return res
  },
  async catalogueFetch ({ commit }, payload) {
    const res = await axios.get(api.catalogueFetch, payload)
    return res
  },
  async statusQuery ({ commit }) {
    const res = await axios.get(api.dictQuery, { parentCode: 'journalStatus' })
    commit('statusQuery', res)
    return res
  },
  async columnQuery ({ commit }) {
    const res = await axios.get(api.dictQuery, { parentCode: 'journalcolumn' })
    commit('columnQuery', res)
    return res
  },
  async journalQuery ({ commit }, payload) {
    const res = await axios.get(api.journalQuery, payload)
    commit('journalQuery', res)
    return res
  }
}

const mutations = {
  catalogueQuery (state, payload) {
    state.catalogueList = payload.data
    state.Total = payload.total
  },
  statusQuery (state, payload) {
    state.dict.journalStatus = payload.data
  },
  columnQuery (state, payload) {
    state.dict.journalcolumn = payload.data
  },
  journalQuery (state, payload) {
    payload.data = payload.data.map(e => ({ ...e, code: e._id }))
    state.dict.journalQuery = payload.data
    state.journalList = payload.data
  },
  userQuery (state, payload) {
    state.userList = payload.data.map(e => e.userList[0])
    state.userTotal = payload.total
  }
}

export default {
  namespaced: true,
  state,
  actions,
  mutations,
  modules: {}
}
